var servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2 =
[
    [ "com::sun::star::table::TableSortDescriptor2", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a941d7336f572db82e3d62705d8e2187e", null ],
    [ "BindFormatsToContent", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#acfc537e4dc64cdc14bddddb534177a9e", null ],
    [ "ContainsHeader", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a5065e7c42974615d07286e452e171dc2", null ],
    [ "CopyOutputData", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a0256ee8718a31dd4301e26891ed3c619", null ],
    [ "IsUserListEnabled", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a787c9c842c608d5f893176a4fa6619db", null ],
    [ "OutputPosition", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#adfd78ac0d1005d334204495b59acd795", null ],
    [ "UserListIndex", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a13962f97105c457e4f5c3517144a5494", null ]
];